state_pulse library
Classes
- HydratedStatePulse
-
Base class that provides state persistence.
Must call
StatePulseStorage.init()before runApp(). - MultiStatePulseListener
- MultiStatePulseProvider
- StatePulse
-
StatePulseBuilder<
T extends ChangeNotifier> -
StatePulseConsumer<
T extends ChangeNotifier> -
A widget that combines both
StatePulseBuilderandStatePulseListenerinto a single, convenient API. -
StatePulseListener<
T extends ChangeNotifier> -
A widget that listens to a
ChangeNotifierstore from StatePulse and triggers a callback whenever the store updates. -
StatePulseProvider<
T extends ChangeNotifier> -
StatePulseSelector<
T extends ChangeNotifier, S> -
A widget that rebuilds only when the selected part of the store changes,
similar to
BlocSelectororSelectorfrom Provider.